@@ -25,6 +25,7 @@
 #include "qzsettings.h"
 #include "browserwindow.h"
 #include "sqldatabase.h"
+#include "statusbar.h"
 
 #include <iostream>
 #include <QDialogButtonBox>
@@ -390,11 +391,15 @@ void BookmarksTools::addFolderToMenu(QObject* receiver, Menu* menu, BookmarkItem
     m->setTitle(title);
     m->setIcon(folder->icon());
 
+    QObject::connect(m, &QMenu::aboutToHide, mApp->getWindow()->statusBar(), &StatusBar::clearMessage);
+
     addFolderContentsToMenu(receiver, m, folder);
 
     QAction* act = menu->addMenu(m);
     act->setData(QVariant::fromValue<void*>(static_cast<void*>(folder)));
     act->setIconVisibleInMenu(true);
+
+    QObject::connect(act, &QAction::hovered, mApp->getWindow()->statusBar(), &StatusBar::clearMessage);
 }
 
 void BookmarksTools::addUrlToMenu(QObject* receiver, Menu* menu, BookmarkItem* bookmark)
@@ -413,6 +418,10 @@ void BookmarksTools::addUrlToMenu(QObject* receiver, Menu* menu, BookmarkItem* b
     QObject::connect(act, SIGNAL(ctrlTriggered()), receiver, SLOT(bookmarkCtrlActivated()));
     QObject::connect(act, SIGNAL(shiftTriggered()), receiver, SLOT(bookmarkShiftActivated()));
 
+    QObject::connect(act, &QAction::hovered, mApp->getWindow()->statusBar(), [=]() {
+        mApp->getWindow()->statusBar()->showMessage(bookmark->url().toString());
+    });
+
     menu->addAction(act);
 }
 
@@ -423,7 +432,8 @@ void BookmarksTools::addSeparatorToMenu(Menu* menu, BookmarkItem* separator)
     Q_ASSERT(menu);
     Q_ASSERT(separator->isSeparator());
 
-    menu->addSeparator();
+    auto* act = menu->addSeparator();
+    QObject::connect(act, &QAction::hovered, mApp->getWindow()->statusBar(), &StatusBar::clearMessage);
 }
 
 void BookmarksTools::addFolderContentsToMenu(QObject *receiver, Menu *menu, BookmarkItem *folder)
