@@ -40,11 +40,7 @@
 #include <QShortcut>
 #include <QStandardPaths>
 #include <QWebEngineHistory>
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-#include <QWebEngineDownloadItem>
-#else
 #include <QWebEngineDownloadRequest>
-#endif
 #include <QtWebEngineWidgetsVersion>
 
 #ifdef Q_OS_WIN
@@ -68,17 +64,17 @@ DownloadManager::DownloadManager(QWidget* parent)
         QtWin::extendFrameIntoClientArea(this, -1, -1, -1, -1);
     }
 #endif
-    ui->clearButton->setIcon(QIcon::fromTheme("edit-clear"));
+    ui->clearButton->setIcon(QIcon::fromTheme(QSL("edit-clear")));
     QzTools::centerWidgetOnScreen(this);
 
     connect(ui->clearButton, &QAbstractButton::clicked, this, &DownloadManager::clearList);
 
-    auto* clearShortcut = new QShortcut(QKeySequence("CTRL+L"), this);
+    auto* clearShortcut = new QShortcut(QKeySequence(QSL("CTRL+L")), this);
     connect(clearShortcut, &QShortcut::activated, this, &DownloadManager::clearList);
 
     loadSettings();
 
-    QzTools::setWmClass("Download Manager", this);
+    QzTools::setWmClass(QSL("Download Manager"), this);
 
     connect(m_model, &DownloadManagerModel::downloadAdded, this, &DownloadManager::downloadAdded);
 }
@@ -86,15 +82,15 @@ DownloadManager::DownloadManager(QWidget* parent)
 void DownloadManager::loadSettings()
 {
     Settings settings;
-    settings.beginGroup("DownloadManager");
-    m_downloadPath = settings.value("defaultDownloadPath", QString()).toString();
-    m_lastDownloadPath = settings.value("lastDownloadPath", QStandardPaths::writableLocation(QStandardPaths::DownloadLocation)).toString();
-    m_closeOnFinish = settings.value("CloseManagerOnFinish", false).toBool();
-    m_useNativeDialog = settings.value("useNativeDialog", DEFAULT_DOWNLOAD_USE_NATIVE_DIALOG).toBool();
+    settings.beginGroup(QSL("DownloadManager"));
+    m_downloadPath = settings.value(QSL("defaultDownloadPath"), QString()).toString();
+    m_lastDownloadPath = settings.value(QSL("lastDownloadPath"), QStandardPaths::writableLocation(QStandardPaths::DownloadLocation)).toString();
+    m_closeOnFinish = settings.value(QSL("CloseManagerOnFinish"), false).toBool();
+    m_useNativeDialog = settings.value(QSL("useNativeDialog"), DEFAULT_DOWNLOAD_USE_NATIVE_DIALOG).toBool();
 
-    m_useExternalManager = settings.value("UseExternalManager", false).toBool();
-    m_externalExecutable = settings.value("ExternalManagerExecutable", QString()).toString();
-    m_externalArguments = settings.value("ExternalManagerArguments", QString()).toString();
+    m_useExternalManager = settings.value(QSL("UseExternalManager"), false).toBool();
+    m_externalExecutable = settings.value(QSL("ExternalManagerExecutable"), QString()).toString();
+    m_externalArguments = settings.value(QSL("ExternalManagerArguments"), QString()).toString();
     settings.endGroup();
 
     if (!m_externalArguments.contains(QLatin1String("%d"))) {
@@ -127,11 +123,7 @@ void DownloadManager::keyPressEvent(QKeyEvent* e)
     QWidget::keyPressEvent(e);
 }
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-void DownloadManager::closeDownloadTab(QWebEngineDownloadItem *item) const
-#else
 void DownloadManager::closeDownloadTab(QWebEngineDownloadRequest *item) const
-#endif
 {
     // Attempt to close empty tab that was opened only for loading the download url
     auto testWebView = [](TabbedWebView *view, const QUrl &url) {
@@ -182,7 +174,7 @@ QWinTaskbarButton *DownloadManager::taskbarButton()
 void DownloadManager::startExternalManager(const QUrl &url)
 {
     QString arguments = m_externalArguments;
-    arguments.replace(QLatin1String("%d"), url.toEncoded());
+    arguments.replace(QLatin1String("%d"), QString::fromUtf8(url.toEncoded()));
 
     QzTools::startExternalProcess(m_externalExecutable, arguments);
     m_lastDownloadOption = ExternalManager;
@@ -217,20 +209,20 @@ void DownloadManager::timerEvent(QTimerEvent* e)
         }
 
         QTime remaining;
-        for (const QTime &time : qAsConst(remTimes)) {
+        for (const QTime &time : std::as_const(remTimes)) {
             if (time > remaining) {
                 remaining = time;
             }
         }
 
         int progress = 0;
-        for (int prog : qAsConst(progresses)) {
+        for (int prog : std::as_const(progresses)) {
             progress += prog;
         }
         progress = progress / progresses.count();
 
         double speed = 0.00;
-        for (double spee : qAsConst(speeds)) {
+        for (double spee : std::as_const(speeds)) {
             speed += spee;
         }
 
@@ -266,7 +258,7 @@ void DownloadManager::clearList()
     Q_EMIT downloadsCountChanged();
 }
 
-void DownloadManager::download(Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS *downloadItem)
+void DownloadManager::download(QWebEngineDownloadRequest *downloadItem)
 {
     QElapsedTimer downloadTimer;
     downloadTimer.start();
@@ -276,13 +268,9 @@ void DownloadManager::download(Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS *downloadItem)
     QString downloadPath;
     bool openFile = false;
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    const QString fileName = QFileInfo(downloadItem->path()).fileName();
-#else
     const QString fileName = downloadItem->downloadFileName();
-#endif
 
-    const bool forceAsk = downloadItem->savePageFormat() != Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::UnknownSaveFormat
+    const bool forceAsk = downloadItem->savePageFormat() != QWebEngineDownloadRequest::UnknownSaveFormat
             || downloadItem->isSavePageDownload();
 
     if (m_useExternalManager) {
@@ -291,7 +279,7 @@ void DownloadManager::download(Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS *downloadItem)
         enum Result { Open = 1, Save = 2, ExternalManager = 3, SavePage = 4, Unknown = 0 };
         Result result = Unknown;
 
-        if (downloadItem->savePageFormat() != Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::UnknownSaveFormat) {
+        if (downloadItem->savePageFormat() != QWebEngineDownloadRequest::UnknownSaveFormat) {
             // Save Page requested
             result = SavePage;
         } else if (downloadItem->isSavePageDownload()) {
@@ -338,17 +326,17 @@ void DownloadManager::download(Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS *downloadItem)
                 Settings().setValue(QSL("DownloadManager/lastDownloadPath"), m_lastDownloadPath);
                 m_lastDownloadOption = SaveFile;
 
-                Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::SavePageFormat format = Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::UnknownSaveFormat;
+                QWebEngineDownloadRequest::SavePageFormat format = QWebEngineDownloadRequest::UnknownSaveFormat;
 
                 if (selectedFilter == mhtml) {
-                    format = Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::MimeHtmlSaveFormat;
+                    format = QWebEngineDownloadRequest::MimeHtmlSaveFormat;
                 } else if (selectedFilter == htmlSingle) {
-                    format = Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::SingleHtmlSaveFormat;
+                    format = QWebEngineDownloadRequest::SingleHtmlSaveFormat;
                 } else if (selectedFilter == htmlComplete) {
-                    format = Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::CompleteHtmlSaveFormat;
+                    format = QWebEngineDownloadRequest::CompleteHtmlSaveFormat;
                 }
 
-                if (format != Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS::UnknownSaveFormat) {
+                if (format != QWebEngineDownloadRequest::UnknownSaveFormat) {
                     downloadItem->setSavePageFormat(format);
                 }
             }
@@ -373,12 +361,8 @@ void DownloadManager::download(Q_WEB_ENGINE_DOWNLOAD_ITEM_CLASS *downloadItem)
     }
 
     // Set download path and accept
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    downloadItem->setPath(downloadPath);
-#else
     downloadItem->setDownloadDirectory(QFileInfo(downloadPath).absoluteDir().absolutePath());
     downloadItem->setDownloadFileName(QFileInfo(downloadPath).fileName());
-#endif
     downloadItem->accept();
 
     // Create download item
